"use client"; // Ensure this is a Client Component

import { useState } from "react";
import Link from "next/link"; // Use Next.js Link
import { FileText, ChevronDownIcon } from "lucide-react";
import {
  FaFile, FaChartPie, FaCube, FaLock, FaChevronDown, FaChevronUp
} from "react-icons/fa";

const Sidebar = () => {
  const [openMenus, setOpenMenus] = useState({
    forms: false,
    tables: false,
    pages: false,
    charts: false,
    uiElements: false,
    authentication: false,
  });

  const toggleMenu = (menu) => {
    setOpenMenus((prev) => ({ ...prev, [menu]: !prev[menu] }));
  };

  return (
    <aside className="w-70 h-screen bg-white text-gray-900 p-5 flex flex-col shadow-lg overflow-y-auto pr-2 scrollbar-hide">
      {/* Logo Section */}
      <div className="flex items-center gap-2 mb-6">
        <h2 className="text-2xl font-bold">TailAdmin</h2>
      </div>

      {/* -------------MENU section */}
      <h3 className="text-sm font-semibold text-gray-500 mt-4">MENU</h3>

      {/* Navigation Links */}
      <nav className="flex flex-col gap-2">
        <Link href="/dashboard" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <img src="/images/icons/grid.svg" alt="Dashboard Icon" width="20" />
          Dashboard
        </Link>

        <Link href="/user-profile" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <img src="/images/icons/user-circle.svg" alt="User Profile Icon" width="20" />
          User Profile
        </Link>

        {/* <Link href="/visits" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <FileText size={20} />
          Api Reports
        </Link> */}
        {/* ------------------------------------------ */}
        <Link href="/pages/visits" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <FileText size={20} />  Visits
        </Link>
        {/* --------------------------------------------- */}
        <Link href="/pages/CustomReport" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <FileText size={20} />
          custom Report
        </Link>
        {/* ---------------------------------------------- */}
        {/* <Link href="/pages/generate-report" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <FileText size={20} />
          generate Report
        </Link> */}
        {/* ----------------------------------------------- */}

        <Link href="/pages/reports" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
          <FileText size={20} />
          Reports
        </Link>

        {/* Forms Dropdown */}
        <button
          onClick={() => toggleMenu("forms")}
          className="flex justify-between items-center w-full p-2 rounded-md hover:bg-gray-200"
        >
          <div className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
            <img src="/images/icons/list.svg" alt="Forms Icon" width="20" />
            Forms
          </div>
          {openMenus.forms ? <FaChevronUp /> : <ChevronDownIcon />}
        </button>
        {openMenus.forms && (
          <div className="pl-10 text-gray-700">
            <Link href="/forms/basic" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">Basic Form</Link>
            <Link href="/forms/advanced" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">Advanced Form</Link>
          </div>
        )}

        {/* Tables Dropdown */}
        <button
          onClick={() => toggleMenu("tables")}
          className="flex justify-between items-center w-full p-2 rounded-md hover:bg-gray-200"
        >
          <div className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
            <img src="/images/icons/table.svg" alt="Tables Icon" width="20" />
            Tables
          </div>
          {openMenus.tables ? <FaChevronUp /> : <FaChevronDown />}
        </button>
        {openMenus.tables && (
          <div className="pl-10 text-gray-700">
            <Link href="/tables/simple" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">Simple Table</Link>
            <Link href="/tables/data" className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">Data Table</Link>
          </div>
        )}

        {/* Pages Dropdown */}
        <button
          onClick={() => toggleMenu("pages")}
          className="flex justify-between items-center w-full p-2 rounded-md hover:bg-gray-200"
        >
          <div className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
            <FaFile /> Pages
          </div>
          {openMenus.pages ? <FaChevronUp /> : <FaChevronDown />}
        </button>

        {/* Other Section */}
        <h3 className="text-sm font-semibold text-gray-500 mt-4">OTHERS</h3>

        {/* Charts Dropdown */}
        <button
          onClick={() => toggleMenu("charts")}
          className="flex justify-between items-center w-full p-2 rounded-md hover:bg-gray-200"
        >
          <div className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
            <FaChartPie /> Charts
          </div>
          {openMenus.charts ? <FaChevronUp /> : <FaChevronDown />}
        </button>

        {/* UI Elements Dropdown */}
        <button
          onClick={() => toggleMenu("uiElements")}
          className="flex justify-between items-center w-full p-2 rounded-md hover:bg-gray-200"
        >
          <div className="flex items-center gap-2 p-2 rounded-md hover:bg-gray-200 text-sm">
            <FaCube /> UI Elements
          </div>
          {openMenus.uiElements ? <FaChevronUp /> : <FaChevronDown />}
        </button>

        {/* Authentication Dropdown */}
        <div className="relative">
          <button
            onClick={() => toggleMenu("authentication")}
            className="flex justify-between items-center w-full p-2 rounded-md hover:bg-gray-200"
          >
            <div className="flex items-center gap-2 p-2 rounded-md text-sm">
              <FaLock /> Authentication
            </div>
            {openMenus.authentication ? <FaChevronUp /> : <FaChevronDown />}
          </button>

          {/* Dropdown Menu */}
          {openMenus.authentication && (
            <div className="mt-2 ml-4 flex flex-col bg-white dark:bg-gray-800 shadow-lg rounded-md">
              <Link href="/signin" className="p-2 text-sm hover:bg-gray-200 dark:hover:bg-gray-700 rounded-md">
                Sign In
              </Link>
              <Link href="/signup" className="p-2 text-sm hover:bg-gray-200 dark:hover:bg-gray-700 rounded-md">
                Sign Up
              </Link>
            </div>
          )}
        </div>
      </nav>

      {/* Footer Section */}
      <div className="mt-auto p-5 bg-gray-50 rounded-lg text-center">
        <h3 className="mb-2 font-semibold text-gray-900">#1 Tailwind CSS Dashboard</h3>
        <p className="text-gray-500 text-sm mb-4">
          Leading Tailwind CSS Admin Template with 400+ UI Components and Pages.
        </p>
        <a
          href="https://tailadmin.com/pricing"
          target="_blank"
          rel="noopener noreferrer"
          className="block bg-blue-500 text-white font-medium py-2 px-4 rounded-md hover:bg-blue-600"
        >
          Purchase Plan
        </a>
      </div>
    </aside>
  );
};

export default Sidebar;