// src/app/dashboard/page.js
"use client"; // Mark this as a client component

import { useRouter } from "next/navigation";
import { useAuth } from "../context/AuthContext"; // Import useAuth
import { useEffect } from "react"; // Import useEffect

export default function DashboardPage() {
  const router = useRouter();
  const { isAuthenticated, loading } = useAuth(); // Get authentication state

  useEffect(() => {
    if (!loading && !isAuthenticated) {
      router.push("/signup"); // Redirect to signup page if not authenticated
    }
  }, [isAuthenticated, loading, router]);

  if (loading) {
    return (
      <div className="flex items-center justify-center min-h-screen bg-gray-900 dark:bg-gray-900  overflow-y-auto pr-2 scrollbar-hide">
        <div className="text-center">
          {/* Spinner */}
          <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-gray-900 dark:border-gray-100 mx-auto"></div>
          {/* Loading Text */}
          <p className="mt-4 text-lg font-semibold text-gray-900 dark:text-gray-100">
            Loading...
          </p>
        </div>
      </div>
    );  }

  if (!isAuthenticated) {
    return null; // Do not render the dashboard if not authenticated
  }

  return (
    <div>
      <h1 className="text-3xl font-bold">Dashboard</h1>
      <p>Welcome to the dashboard!</p>
    </div>
  );
}