"use client";
import React, { useState, useEffect } from "react";

const Visits = () => {
    const [data, setData] = useState(null);
    const [deviceData, setDeviceData] = useState(null);
    const [browserData, setBrowserData] = useState(null);
    const [osData, setOsData] = useState(null);
    const [lastMonthData, setLastMonthData] = useState(null);
    const [lastTwoMonthsData, setLastTwoMonthsData] = useState(null);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);

    // Fetch data from the API
    const fetchData = async (endpoint, setDataFunction) => {
        try {
            const response = await fetch(`/api/proxy?domain=meerafirms.in&endpoint=${endpoint}`);
            if (!response.ok) {
                const errorData = await response.json(); // Parse the error response
                throw new Error(errorData.error || `HTTP Error: ${response.status}`);
            }
            const result = await response.json();
            setDataFunction(result);
            console.log(`${endpoint} Data:`, result); // Log the data for debugging
        } catch (err) {
            console.error(`Error fetching ${endpoint}:`, err);
            setError(err.message);
        }
    };

    useEffect(() => {
        const fetchAllData = async () => {
            setLoading(true);
            await Promise.all([
                fetchData("visits/total-visits", setData),
                fetchData("visits/total-visits?fields=device", setDeviceData),
                fetchData("visits/total-visits?fields=device,browser,os", setBrowserData),
                fetchData("visits/last-month", setLastMonthData),
                fetchData("visits/last-2-months", setLastTwoMonthsData),
            ]);
            setLoading(false);
        };

        fetchAllData();
    }, []);

    return (
        <div>
            <div className="m-2 p-4 pl-10 pr-10 bg-white border border-gray-200 rounded-2xl">
                <h2 className="text-lg font-bold mb-2">Website Visits</h2>
                {loading && <p>Loading...</p>}
                {error && <p className="text-red-500">Error: {error}</p>}
                {data && (
                    <>
                        <h1>Total Visits: {data["Total Visits"]}</h1>
                        <h1>Total Views: {data["Total Views"]}</h1>
                    </>
                )}
            </div>

            <div className="m-2 p-4 pl-10 pr-10 bg-white border border-gray-200 rounded-2xl">
                <h2 className="text-lg font-bold mb-2">Device Data</h2>
                {deviceData && Object.entries(deviceData.Devices || {}).map(([key, value]) => (
                    <h1 key={key}>{key} Visits: {value}</h1>
                ))}
            </div>

            <div className="m-2 p-4 pl-10 pr-10 bg-white border border-gray-200 rounded-2xl">
                <h2 className="text-lg font-bold mb-2">Browser Data</h2>
                {browserData && Object.entries(browserData.Browsers || {}).map(([key, value]) => (
                    <h1 key={key}>{key} Visits: {value}</h1>
                ))}
            </div>

            <div className="m-2 p-4 pl-10 pr-10 bg-white border border-gray-200 rounded-2xl">
                <h2 className="text-lg font-bold mb-2">OS Data</h2>
                {browserData && Object.entries(browserData.OS || {}).map(([key, value]) => (
                    <h1 key={key}>{key} Visits: {value}</h1>
                ))}
            </div>

            <div className="m-2 p-4 pl-10 pr-10 bg-white border border-gray-200 rounded-2xl">
                <h2 className="text-lg font-bold mb-2">Last Month Data</h2>
                {lastMonthData && Object.entries(lastMonthData || {}).map(([key, value]) => (
                    <h1 key={key}>{key} Visits: {value}</h1>
                ))}
            </div>

            <div className="m-2 p-4 pl-10 pr-10 bg-white border border-gray-200 rounded-2xl">
                <h2 className="text-lg font-bold mb-2">Last 2 Months Data</h2>
                {lastTwoMonthsData && Object.entries(lastTwoMonthsData || {}).map(([key, value]) => (
                    <h1 key={key}>{key} Visits: {value}</h1>
                ))}
            </div>
        </div>
    );
};

export default Visits;